@@ -131,7 +131,7 @@ def upload_features_command(command_args, config):
     feature_paths = set()
     for path in paths:
         path = path.replace(os.sep, '/')
-        globs = glob.glob(path) + glob.glob(os.path.join(path, '**'), recursive=True)
+        globs = glob.glob(path, recursive=True) + glob.glob(os.path.join(path, '**'), recursive=True)
         [feature_paths.add(f.replace(os.sep, '/')) for f in globs if f.endswith('.feature')]
     feature_paths = list(sorted(feature_paths))
 
@@ -152,9 +152,9 @@ def upload_features_command(command_args, config):
         for scenario in feature.scenarios:
             occurrences = [issue['key'] for issue in issues if scenario.name == issue['fields']['summary']]
 
-            if not scenario.test_id:
+            if not scenario.test_id and occurrences:
                 errors.append(f"{scenario.name} has no id but already exists in test repository {occurrences}")
-            else:
+            elif scenario.test_id:
                 if not occurrences:
                     errors.append(f"{scenario.name} [{scenario.test_id}] "
                                   f"has different name in test repository")
@@ -310,9 +310,9 @@ if __name__ == '__main__':
     # main([Commands.SCENARIOS])
     #
     # main([Commands.UPLOAD_FEATURES, '-h'])
-    # main([Commands.UPLOAD_FEATURES, r'C:\workspaces\bddsync/features/Verisure OWA/Wrapper Android/actionplansWrapperAndroid.feature'])
+    main([Commands.UPLOAD_FEATURES, r'C:\workspaces\verisureowatesting\features\**\cameras*'])
     # main([Commands.UPLOAD_FEATURES, 'features/*Wrapper'])
     #
     # main([Commands.UPLOAD_RESULTS, '-h'])
     # main([Commands.UPLOAD_RESULTS, '-e', 'STG', '-f', 'RW21_23', '-p', 'DCH-6689'])
-    main([Commands.UPLOAD_RESULTS, 'output/result.json'])
+    # main([Commands.UPLOAD_RESULTS, 'output/result.json'])
